@@ -8,13 +8,13 @@ class Hub(ComponentResource):
         super().__init__('vdc:network:Hub', name, {}, opts)
 
         # Create Hub resource group
-        hub_rg = resource_group.resource_group('Hub', props, parent = self)
+        # hub_rg = resource_group.resource_group('Hub', props, parent = self)
 
         hubResources = [route_table, vnet, firewall, vpn_gateway, bastion_hosts, resource_group]
 
         for resource in hubResources:
             resource.location = props.location
-            resource.resource_group_name = hub_rg.name
+            resource.resource_group_name = props.resource_group_name
             resource.self = self
             resource.tags = props.tags
 
