@@ -1,8 +1,9 @@
 from pulumi import ResourceOptions
 from pulumi.resource import CustomTimeouts
 import pulumi_azure_native.network as network
+from pulumi_azuread import provider
 
-def vpn_gateway(stem, subnet_id, depends_on=None):
+def vpn_gateway(stem, subnet_id, provider=None,depends_on=None):
     vpn_gw_pip = network.PublicIPAddress(
         f'vpngwpip-{stem}',
         resource_group_name=resource_group_name,
@@ -34,6 +35,7 @@ def vpn_gateway(stem, subnet_id, depends_on=None):
         )],
         tags=tags,
         opts=ResourceOptions(
+            provider=provider,
             parent=self,
             depends_on=depends_on,
             custom_timeouts=CustomTimeouts(
@@ -46,7 +48,7 @@ def vpn_gateway(stem, subnet_id, depends_on=None):
     return vpn_gw
 
 
-def local_gateway(stem, onprem_gw_ip, addr_space, depends_on=None):
+def local_gateway(stem, onprem_gw_ip, addr_space, provider=None,depends_on=None):
     local_gw = network.LocalNetworkGateway(
         f'lngw-{stem}',
         local_network_gateway_name = f'lngw-{stem}',
@@ -57,6 +59,7 @@ def local_gateway(stem, onprem_gw_ip, addr_space, depends_on=None):
         ),
         tags=tags,
         opts=ResourceOptions(
+            provider=provider,
             parent=self,
             depends_on=depends_on,
         ),
